@@ -1,5 +1,5 @@
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from vng_api_common.descriptors import GegevensGroepType
 
@@ -20,6 +20,8 @@ class Person(models.Model):
     address_street = models.CharField(_("street name"), max_length=255)
     address_number = models.CharField(_("house number"), max_length=10)
 
-    address = GegevensGroepType({"street": address_street, "number": address_number}, required=False)
+    address = GegevensGroepType(
+        {"street": address_street, "number": address_number}, required=False
+    )
 
     group = models.ForeignKey("Group", null=True, on_delete=models.CASCADE)
