@@ -2,7 +2,7 @@ import uuid
 
 from django.contrib.postgres.fields import ArrayField
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ..constants import ComponentTypes, VertrouwelijkheidsAanduiding
 from ..decorators import field_default
